@@ -1,6 +1,8 @@
-from requests import get
 import re, json
 from datetime import date
+from https import idk
+requests = idk()
+get = idk().get
 #cars of nitrotype
 cars = {
     1 : 'Lamborgotti Mephisto SS',
@@ -493,7 +495,7 @@ class Racer:
             for elem in newdata['cars']:
                 if elem[1] == 'owned':
                     self.carIDs.append(elem[0])
-
+            self.newdata = newdata
             self.username = newdata['username'].title()
 
             display_name = newdata['displayName'] or self.username
